aboutsummaryrefslogtreecommitdiffstats
path: root/fetchmail.h
diff options
context:
space:
mode:
Diffstat (limited to 'fetchmail.h')
-rw-r--r--fetchmail.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/fetchmail.h b/fetchmail.h
index 8c4ee3a3..5a146ce8 100644
--- a/fetchmail.h
+++ b/fetchmail.h
@@ -87,8 +87,8 @@ struct hostrec
int norewrite;
int skip;
- /* current, previous state of mailbox (initially from .fetchids) */
- struct idlist *saved, *current;
+ /* unseen, previous state of mailbox (initially from .fetchids) */
+ struct idlist *saved, *unseen;
/* internal use */
int active;
@@ -148,7 +148,7 @@ int doIMAP (struct hostrec *);
void initialize_saved_lists(struct hostrec *, char *);
void save_uid(struct idlist **, int, char *);
void free_uid_list(struct idlist **);
-int delete_uid(struct idlist **, char *);
+int delete_uid(struct idlist **, int);
int uid_in_list(struct idlist **, char *);
void update_uid_lists(struct hostrec *);
void write_saved_lists(struct hostrec *, char *);